function p = MG_RawData_to_Pairs(x, params)
% MG_RAWDATA_TO_PAIRS - find positions of mathcing-pairs-of-segments based
% on original position data
% p = MG_RawData_to_Pairs(x, params) - 
% input:
% x - [Time, Red pos, Blue pos]
% params (optional) - 
%   .pair_thr (=20) - maximal number of samples allowed between events in a pair
%   .test (=0) - show the segments for debug
% output:
% p -  matrix of [start, end] of segments
%

% Default Values for Optional Inputs %
if ~exist('params','var') || isempty(params)
	params = [];
end

params = add_default( params, 'pair_thr', 20 );
params = add_default( params, 'test', 0 );

% segments from signals 
[ ~, seg_ind_red ] = MG_Segment_Vel_One_Player(x(:,1), x(:,2), params );  % first output is cell-array of actual segments
[ ~, seg_ind_blue ] = MG_Segment_Vel_One_Player(x(:,1), x(:,3), params );

%[ FIX - 30.4.15]
if isempty( seg_ind_red) || isempty( seg_ind_blue ),
    p = [];
    return
end

%  find matching segments, according to middle point
m1 = mean(seg_ind_red, 2);
m2 = mean(seg_ind_blue, 2);
inds = match_event_pairs(m1, m2, params.pair_thr); % first output is 'pair indcies on list of events <m1>, <m2>

% find start, end point of matched segment (covering both)
p = zeros( size( inds,1 ), 2 );
for k = 1  : size( inds,1 ),
    % start point
    p(k,1) = min( seg_ind_red(inds(k,1), 1), seg_ind_blue(inds(k,2), 1) );
    p(k,2) = max( seg_ind_red(inds(k,1), 2), seg_ind_blue(inds(k,2), 2) );
end

if params.test,
    test(x,p);
end

%%%%%%%%%%%%%%%%
function test( x, p )
t = x(:,1);
clf

v1 = vel_acc_with_bfilt( x(:,2) );
v2 = vel_acc_with_bfilt( x(:,3) );

plot( t, abs(v1), 'Color', 'r' );
hold on
plot( t, abs(v2), 'Color', 'b' );


for k = 1 : size(p,1), 
    h=line([t(p(k,1)) t(p(k,2))], [0 0],'Color','g','LineWidth',3); 
    pause
    set(h,'Visible','off'); 
end

hold off