function [ seg, azc_num, azc1, azc2 ] = MG_Tools_Segments_Acc_Zero_Cross( x, fps, params )
% MG_TOOLS_SEGMENTS_ACC_ZERO_CROSS - number of acceleration zero-crossing
% (AZC), per player, in valid paired-segment
% [ seg, azc_num, azc1, azc2 ] = MG_Tools_Segments_Acc_Zero_Cross( x, fps ) - 
% input:
% x - [t,p1,p2]
% fps - frame per sec (optional, =50)
% params - 
% 
% output:
% seg - [start,end]
% azc_num - per segment, [num of AZC for Red, num of AZC for Blue]
% azc1, azc2 - acc-zero-cross vectors for the two players (same size as
% <x>, 1 == AZC point)
%
% 2016-08-30: 
% add option for params.butter_filter = 1 (defult = 0), work with Butter filter instead of Bfilt


if ~exist('fps','var') || isempty(fps),
    const = MG_Default_Const;
    fps = const.Samples_Per_Sec;
end
    
seg = MG_RawData_to_Pairs( x, params );

p1 = x(:,2);
p2 = x(:,3);
azc1 =  find_acc_zero_cross(p1, fps, params);
azc2 =  find_acc_zero_cross(p2, fps, params);

for i = 1 : size(seg,1),
    azc_num( i, 1 ) = length( find( azc1( seg(i,1) : seg(i,2) ) ) ); %#ok<*AGROW>
    azc_num( i, 2 ) = length( find( azc2( seg(i,1) : seg(i,2) ) ) );
end
