function [y,B,A] = jason_butter_filter(x, cutoff, sample_rate)
% JASON_BUTTER_FILTER - 
%  [y,B,A] = jason_butter_filter(x, cutoff, sample_rate) - 
% 4th order 2-way Butterworth filter with a cutoff 
% input:
% x - vector
% cutoff - filter above this freq
% sample_rate - in Hz
%
% output:
% y - filter
% B,A - parameters from butter() to filtfilt(). 
% usage: z = filtfilt(B,A,z);

% 10-April-2014
x = remove_nan(x);

Wn = cutoff / (sample_rate/2);
[B,A] = butter(2,Wn); % 4th order filter, filtfilt doubles the filter order
y = filtfilt(B,A,x);

