function [ vel acc jerk ] = vel_acc_with_bfilt(x, params)
% VEL_ACC_WITH_BFILT - 
% [ vel, acc, jerk ] = vel_acc_with_bfilt(x, params) - smooth x, 
% smooth vel, get acc, get 'jerk' (= change of accelartion)
% input:
% x - position
% params - 
%   .smooth = number of time to apply bfilt(default = 3)
%             note that this is done for each derivative
%   .params.draw  (default= 0)
%   .do_acc, do_jerk = do higher derivatives (default= 0)
% output:
% vel - 
% acc - 
% jerk - 
% 2012-11-19: compute usually only Vel to save computing time.

% Default Values for Optional Inputs %
if ~exist('params','var') || isempty(params) || ~isfield(params,'smooth'),
    params.smooth = 3;
end

if ~isfield(params,'draw'),
    params.draw = 0;
end

params = add_default( params, 'do_acc', 0);
params = add_default( params, 'do_jerk', 0);

if params.do_jerk, params.do_acc = 1;end

if size(x,1) < size(x,2),
    x = x';
    row_vec = 1;
else
    row_vec = 0;
end

% check that is 1-D
if size(x,2) > 1,
    error('<x> should be 1-D')
end

vel = do_one(x,params);

if params.do_acc,
    acc = do_one(vel,params);    
else    
    acc = [];
end

if params.do_jerk,
    jerk = do_one(acc,params);
else    
    jerk = [];
end


if row_vec,
    vel = vel';
    acc = acc';
    jerk = jerk';
end


if params.draw,
    clf
    for k = 1 : 4,
        subplot(4,1,k);    
        switch k,
            case 1,
                  plot(x);
                  title('position');
            case 2,
                  plot(abs(vel));
                  title('abs velocity');
            case 3,
                  plot(abs(acc));
                  title('abs acceleration');
            case 4,
                  plot(abs(jerk));
                  title('abs jerk');
        end
    end
end    
    
%%%%%%%%%%%%%%%%%
function y = do_one(x,params)
for k = 1 : params.smooth,
    x = bfilt(x);
end

y = [0; diff(x)];